@@ -1,17 +1,16 @@
 import pandas as pd
 
 from visions.relations.relations import InferenceRelation
+from visions.relations.relations_utils import values_are_consecutive
 from visions.types.ordinal import to_ordinal
 
 
-def check_consecutive(l: list) -> bool:
-    return sorted(l) == list(range(min(l), max(l) + 1))
-
-
-def is_ordinal_str(s: pd.Series) -> bool:
+def is_ordinal_str(s: pd.Series, state: dict) -> bool:
     if s.str.len().max() == 1:
         unique_values = list(s[s.notna()].str.lower().unique())
-        return "a" in unique_values and check_consecutive(list(map(ord, unique_values)))
+        return "a" in unique_values and values_are_consecutive(
+            list(map(ord, unique_values))
+        )
     else:
         return False
 
