@@ -1,21 +1,33 @@
 from typing import Sequence
 
-import numpy as np
 import pandas as pd
 from pandas.api import types as pdt
 
 from visions.relations import IdentityRelation, InferenceRelation, TypeRelation
-from visions.types.float import test_is_float
+from visions.types.float import string_is_float
 from visions.types.type import VisionsBaseType
 from visions.utils.coercion import test_utils
 
 
-def test_string_is_complex(series) -> bool:
-    coerced_series = test_utils.option_coercion_evaluator(to_complex)(series)
-    return coerced_series is not None and not test_is_float(series)
+def test_imaginary_in_string(
+    series: pd.Series, imaginary_indicator: tuple = ("j", "i")
+):
+    return any(any(v in s for v in imaginary_indicator) for s in series)
 
 
-def to_complex(series: pd.Series) -> bool:
+def string_is_complex(series, state: dict) -> bool:
+    def f(s):
+        return s.apply(complex)
+
+    coerced_series = test_utils.option_coercion_evaluator(f)(series)
+    return (
+        coerced_series is not None
+        and not string_is_float(series, state)
+        and test_imaginary_in_string(series)
+    )
+
+
+def to_complex(series: pd.Series, state: dict) -> bool:
     return series.apply(complex)
 
 
@@ -25,7 +37,7 @@ def _get_relations(cls) -> Sequence[TypeRelation]:
     relations = [
         IdentityRelation(cls, Generic),
         InferenceRelation(
-            cls, String, relationship=test_string_is_complex, transformer=to_complex
+            cls, String, relationship=string_is_complex, transformer=to_complex
         ),
     ]
     return relations
@@ -46,5 +58,5 @@ class Complex(VisionsBaseType):
         return _get_relations(cls)
 
     @classmethod
-    def contains_op(cls, series: pd.Series) -> bool:
+    def contains_op(cls, series: pd.Series, state: dict) -> bool:
         return pdt.is_complex_dtype(series)
