@@ -8,9 +8,9 @@ from visions.types.type import VisionsBaseType
 
 
 def _get_relations(cls) -> Sequence[TypeRelation]:
-    from visions.types import Generic
+    from visions.types import Integer
 
-    relations = [IdentityRelation(cls, Generic)]
+    relations = [IdentityRelation(cls, Integer)]
     return relations
 
 
@@ -28,5 +28,5 @@ class Count(VisionsBaseType):
         return _get_relations(cls)
 
     @classmethod
-    def contains_op(cls, series: pd.Series) -> bool:
+    def contains_op(cls, series: pd.Series, state: dict) -> bool:
         return pdt.is_unsigned_integer_dtype(series)
