@@ -1,16 +1,15 @@
-from typing import List, Sequence
+from typing import Sequence
 
-import numpy as np
 import pandas as pd
-import pandas.api.types as pdt
+from pandas.api import types as pdt
 
-from visions.types import Generic
-from visions.relations import IdentityRelation, InferenceRelation, TypeRelation
+from visions.relations import IdentityRelation, TypeRelation
 from visions.types.type import VisionsBaseType
-from visions.utils.coercion import test_utils
 
 
 def _get_relations(cls) -> Sequence[TypeRelation]:
+    from visions import Generic
+
     relations = [IdentityRelation(cls, Generic)]
     return relations
 
@@ -20,7 +19,7 @@ class Numeric(VisionsBaseType):
 
     Examples:
         >>> x = pd.Series([1, 2, 3])
-        >>> x in visions.Integer
+        >>> x in visions.Numeric
         True
     """
 
@@ -29,5 +28,5 @@ class Numeric(VisionsBaseType):
         return _get_relations(cls)
 
     @classmethod
-    def contains_op(cls, series: pd.Series) -> bool:
-        return pdt.is_numeric(series)
+    def contains_op(cls, series: pd.Series, state: dict) -> bool:
+        return pdt.is_numeric_dtype(series)
