@@ -34,5 +34,5 @@ class Ordinal(VisionsBaseType):
         return _get_relations(cls)
 
     @classmethod
-    def contains_op(cls, series: pd.Series) -> bool:
+    def contains_op(cls, series: pd.Series, state: dict) -> bool:
         return pdt.is_categorical_dtype(series) and series.cat.ordered
