@@ -5,13 +5,18 @@ from pandas.api import types as pdt
 
 from visions.relations import IdentityRelation, TypeRelation
 from visions.types.type import VisionsBaseType
+from visions.utils import func_nullable_series_contains
+
+
+@func_nullable_series_contains
+def series_is_string(series: pd.Series, state: dict):
+    return all(isinstance(v, str) for v in series)
 
 
 def _get_relations(cls) -> Sequence[TypeRelation]:
     from visions.types import Object
 
     relations = [IdentityRelation(cls, Object)]
-
     return relations
 
 
@@ -32,18 +37,11 @@ class String(VisionsBaseType):
         return _get_relations(cls)
 
     @classmethod
-    def contains_op(cls, series: pd.Series) -> bool:
+    def contains_op(cls, series: pd.Series, state: dict) -> bool:
         # TODO: without the object check this passes string categories... is there a better way?
         if pdt.is_categorical_dtype(series):
             return False
         elif not pdt.is_object_dtype(series):
-            if pandas_has_string_dtype_flag and pdt.is_string_dtype(series):
-                return True
-            return False
+            return pandas_has_string_dtype_flag and pdt.is_string_dtype(series)
 
-        if series.hasnans:
-            series = series.dropna()
-            if series.empty:
-                return False
-
-        return all(isinstance(v, str) for v in series)
+        return series_is_string(series)
