@@ -1,10 +1,10 @@
 from visions.types import (
-    Generic,
     Boolean,
     Categorical,
     Complex,
     DateTime,
     Float,
+    Generic,
     Geometry,
     Integer,
     Object,
@@ -32,7 +32,7 @@ class GeometrySet(VisionsTypeset):
 
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         types = {
             Generic,
             Boolean,
