@@ -1,10 +1,10 @@
 from visions.types import (
-    Generic,
     Boolean,
     Categorical,
     Complex,
     DateTime,
     Float,
+    Generic,
     Integer,
     Object,
     String,
@@ -30,7 +30,7 @@ class StandardSet(VisionsTypeset):
 
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         types = {
             Generic,
             Boolean,
