@@ -1,7 +1,7 @@
 import pytest
 
-from tests.series import get_series
 from visions import EmailAddress
+from visions.test.series import get_geometry_series, get_series
 from visions.types import Generic
 from visions.typesets import CompleteSet
 
@@ -10,7 +10,7 @@ typeset += EmailAddress
 
 
 def pytest_generate_tests(metafunc):
-    _test_suite = get_series()
+    _test_suite = get_series() + get_geometry_series()
     if metafunc.function.__name__ in ["test_consistency", "test_traversal_mutex"]:
         argsvalues = []
         for series in _test_suite:
@@ -21,7 +21,9 @@ def pytest_generate_tests(metafunc):
 
 
 def test_consistency(series):
-    assert series in typeset.detect_series_type(series)
+    detected_type = typeset.detect_type(series)
+    message = f"Detected type {detected_type} for series {series.name} but {detected_type}.contains_op(series) -> False"
+    assert series in detected_type, message
 
 
 def _traverse_relation_graph(series, G, node=Generic):
